@@ -40,7 +40,7 @@ class Runpipe:
             data_cmd += ['--no_introns']
         data_cmd = ' '.join(data_cmd)
 
-        count_cmd = 'DNBC4tools count --name %s --raw_matrix %s/%s/01.data/raw_matrix --bam %s/%s/01.data/final.bam --calling_method %s --expectcells %s --forcecells %s --minumi 500 --cDNAbarcodeCount %s/%s/01.data/cDNA_barcode_counts_raw.txt --Indexreads %s/%s/01.data/Index_reads.fq.gz --oligobarcodeCount %s/%s/01.data/Index_barcode_counts_raw.txt --thread %s --oligotype %s --outdir %s'\
+        count_cmd = 'DNBC4tools count --name %s --raw_matrix %s/%s/01.data/raw_matrix --bam %s/%s/01.data/final.bam --calling_method %s --expectcells %s --forcecells %s --minumi 1000 --cDNAbarcodeCount %s/%s/01.data/cDNA_barcode_counts_raw.txt --Indexreads %s/%s/01.data/Index_reads.fq.gz --oligobarcodeCount %s/%s/01.data/Index_barcode_counts_raw.txt --thread %s --oligotype %s --outdir %s'\
         %(self.name,self.outdir,self.name,self.outdir,self.name,self.calling_method,self.expectcells,self.forcecells,self.outdir,self.name,self.outdir,self.name,self.outdir,self.name,self.thread,self.oligotype,self.outdir)
 
         analysis_cmd = 'DNBC4tools analysis --name %s --matrix %s/%s/02.count/filter_matrix --species %s --outdir %s --mtgenes %s'\
@@ -95,10 +95,10 @@ def parse_run(parser):
     parser.add_argument('--calling_method',metavar='STR',help='Cell calling method, Choose from barcoderanks and emptydrops, [default: emptydrops].', default='emptydrops')
     parser.add_argument('--expectcells',metavar='INT',help='Expected number of recovered beads, [default: 3000].', default=3000)
     parser.add_argument('--forcecells',metavar='INT',help='Force pipeline to use this number of beads.', default=0)
-    parser.add_argument('--mtgenes',metavar='LIST',default='auto',help='Set mitochondrial genes(mtgene list file path) or auto, [default: auto].')
-    parser.add_argument('--process', metavar='TEXT',help='Custom your analysis steps, steps are separated by commas, [default: data,count,analysis,report].',type=str,default='data,count,analysis,report')
+    parser.add_argument('--mtgenes',metavar='FILE',default='auto',help='Set mitochondrial genes(mtgene list file path) or auto, [default: auto].')
+    parser.add_argument('--process', metavar='STR',help='Custom your analysis steps, steps are separated by commas, [default: data,count,analysis,report].',type=str,default='data,count,analysis,report')
     parser.add_argument('--no_introns', action='store_true',help='Not include intronic reads in count.')
     parser.add_argument('--mixseq', action='store_true',help='cDNA and oligo sequence in same chip.')
-    parser.add_argument('--no_bam', action='store_true',help='Do not move filter bam file to output dir.')
+    parser.add_argument('--no_bam', action='store_true',help='Do not move filter bam file to the output dir.')
     parser.add_argument('--dry', help=' Do not execute the pipeline. Generate a pipeline shell file.',action='store_true')
     return parser
\ No newline at end of file
